#! /bin/sh -e
# tup - A file-based build system
#
# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# Make sure 'tup' works without a .tup directory or Tupfile.ini present.

. ./tup.sh

tmpdir="/tmp/tup-t4158-$$"
cleanup()
{
	cd /tmp
	rm -rf $tmpdir
}

trap cleanup EXIT INT TERM
cleanup
mkdir $tmpdir
cd $tmpdir
output="$tupcurdir/$tuptestdir/output.txt"
tup 2> $output || true

if ! grep 'No .tup directory found' $output > /dev/null; then
	echo "Error: Expected tup to print an error message." 1>&2
	exit 1
fi

eotup
